==> 2.4.11.tar.gz: cloudlog/application/language/english/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Attention: you need to set an active station location.';

$lang['notice_turn_the_radio_on'] = 'You have made no QSOs today; time to turn on the radio!';

$lang['general_word_important'] = 'Important';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Choose file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Date';
$lang['general_word_time'] = 'Time';
$lang['general_word_datetime'] = 'Date/Time';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'Name';
$lang['general_word_location'] = 'Location';
$lang['general_word_comment'] = 'Comment';
$lang['general_word_general'] = 'General';
$lang['general_word_satellite'] = 'Satellite';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notes';
$lang['general_word_country'] = 'Country';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Total';
$lang['general_word_year'] = 'Year';
$lang['general_word_month'] = 'Month';

$lang['general_word_worked'] = 'Worked';
$lang['general_word_confirmed'] = 'Confirmed';
$lang['general_word_needed'] = 'Needed';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'No';
$lang['general_word_yes'] = 'Yes';
$lang['general_word_method'] = 'Method';

$lang['general_word_sent'] = 'Sent';
$lang['general_word_received'] = 'Received';
$lang['general_word_requested'] = 'Requested';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL Card';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL Cards';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Edit QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Mark QSL Received (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Mark QSL Received (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Mark QSL Received (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Mark QSL Sent (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Mark QSL Sent (Direct)';
$lang['general_mark_qsl_requested'] = 'Mark QSL Card Requested';
$lang['general_mark_qsl_requested_bureau'] = 'Mark QSL Card Requested (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Mark QSL Card Requested (Direct)';
$lang['general_mark_qsl_not_required'] = 'Mark QSL Card Not Required';

$lang['general_delete_qso'] = 'Delete QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Total Distance';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Station Location';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Callsign';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Sent';
$lang['gen_hamradio_rst_rcvd'] = 'Recv\'d';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequency';
$lang['gen_hamradio_frequency_rx'] = 'Frequency (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Transmit Power (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Satellite Name';
$lang['gen_hamradio_satellite_mode'] = 'Satellite Mode';

$lang['gen_hamradio_logbook'] = 'Logbook';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA State';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Reference';
$lang['gen_hamradio_sota_reference'] = 'SOTA Reference';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Reference';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq'] = "If you don't know your CQ Zone then <a href='https://zone-check.eu/?m=cq' target='_blank'>click here</a> to find it";
$lang['gen_find_zone_itu'] = "If you don't know your ITU Zone then <a href='https://zone-check.eu/?m=itu' target='_blank'>click here</a> to find it";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'You have had';
$lang['dashboard_qsos_today'] = 'QSOs Today!';
$lang['dashboard_qso_breakdown'] = 'QSOs Breakdown';
$lang['dashboard_countries_breakdown'] = 'Countries Breakdown';

$lang['gen_from_date'] = 'From date';
$lang['gen_to_date'] = 'To date';

$lang['gen_this_qso_was_confirmed_on'] = 'This QSO was confirmed on';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

==> 2.5.2.tar.gz: cloudlog/application/language/english/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Attention: you need to set an active station location.';

$lang['notice_turn_the_radio_on'] = 'You have made no QSOs today; time to turn on the radio!';

$lang['general_word_important'] = 'Important';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Choose file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";

$lang['general_word_date'] = 'Date';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Time';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Date/Time';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'Name';
$lang['general_word_location'] = 'Location';
$lang['general_word_comment'] = 'Comment';
$lang['general_word_general'] = 'General';
$lang['general_word_satellite'] = 'Satellite';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Notes';
$lang['general_word_country'] = 'Country';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Total';
$lang['general_word_year'] = 'Year';
$lang['general_word_month'] = 'Month';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Worked';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Confirmed';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Needed';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'No';
$lang['general_word_yes'] = 'Yes';
$lang['general_word_method'] = 'Method';

$lang['general_word_sent'] = 'Sent';
$lang['general_word_received'] = 'Received';
$lang['general_word_requested'] = 'Requested';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL Card';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL Cards';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Edit QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Mark QSL Received (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Mark QSL Received (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Mark QSL Received (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Mark QSL Sent (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Mark QSL Sent (Direct)';
$lang['general_mark_qsl_requested'] = 'Mark QSL Card Requested';
$lang['general_mark_qsl_requested_bureau'] = 'Mark QSL Card Requested (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Mark QSL Card Requested (Direct)';
$lang['general_mark_qsl_not_required'] = 'Mark QSL Card Not Required';

$lang['general_delete_qso'] = 'Delete QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Total Distance';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Station Location';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Callsign';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Sent';
$lang['gen_hamradio_rst_rcvd'] = 'Recv\'d';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequency';
$lang['gen_hamradio_frequency_rx'] = 'Frequency (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Transmit Power (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Satellite Name';
$lang['gen_hamradio_satellite_mode'] = 'Satellite Mode';

$lang['gen_hamradio_logbook'] = 'Logbook';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA State';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Reference';
$lang['gen_hamradio_sota_reference'] = 'SOTA Reference';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Reference';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'You have had';
$lang['dashboard_qsos_today'] = 'QSOs Today!';
$lang['dashboard_qso_breakdown'] = 'QSOs Breakdown';
$lang['dashboard_countries_breakdown'] = 'Countries Breakdown';

$lang['gen_from_date'] = 'From date';
$lang['gen_to_date'] = 'To date';

$lang['gen_this_qso_was_confirmed_on'] = 'This QSO was confirmed on';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';
